summaryrefslogtreecommitdiffstats
path: root/native/src/overlay.rs
diff options
context:
space:
mode:
Diffstat (limited to 'native/src/overlay.rs')
-rw-r--r--native/src/overlay.rs8
1 files changed, 2 insertions, 6 deletions
diff --git a/native/src/overlay.rs b/native/src/overlay.rs
index 16d8bb31..1c3d0fb9 100644
--- a/native/src/overlay.rs
+++ b/native/src/overlay.rs
@@ -90,12 +90,8 @@ where
mouse::Interaction::Idle
}
- /// Whether the [`Overlay`] contains the cursor
- fn contains_cursor(
- &self,
- layout: Layout<'_>,
- cursor_position: Point,
- ) -> bool {
+ /// Returns true if the cursor is over the [`Overlay`]
+ fn is_over(&self, layout: Layout<'_>, cursor_position: Point) -> bool {
layout.bounds().contains(cursor_position)
}
}